@@ -21,17 +21,16 @@
 // Own
 #include "History.h"
 
+#include "konsoledebug.h"
+#include "KonsoleSettings.h"
+
 // System
+#include <errno.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
-#include <sys/mman.h>
-#include <unistd.h>
-#include <errno.h>
 
 // KDE
-#include <QDebug>
-
 #include <QDir>
 #include <qplatformdefs.h>
 #include <QStandardPaths>
@@ -61,38 +60,44 @@ Q_GLOBAL_STATIC(QString, historyFileLocation)
 */
 
 // History File ///////////////////////////////////////////
-HistoryFile::HistoryFile()
-    : _fd(-1),
-      _length(0),
-      _fileMap(0),
-      _readWriteBalance(0)
+HistoryFile::HistoryFile() :
+    _length(0),
+    _fileMap(0),
+    _readWriteBalance(0)
 {
     // Determine the temp directory once
     // This class is called 3 times for each "unlimited" scrollback.
     // This has the down-side that users must restart to
-    // load changes (currently only 2 choices).
+    // load changes.
     if (!historyFileLocation.exists()) {
         KConfigGroup configGroup(KSharedConfig::openConfig(), "FileLocation");
         if (configGroup.readEntry("scrollbackUseCacheLocation", false)) {
             *historyFileLocation() = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
+        } else if (configGroup.readEntry("scrollbackUseSpecifiedLocation", false)) {
+            const QUrl specifiedUrl = KonsoleSettings::scrollbackUseSpecifiedLocationDirectory();
+            *historyFileLocation() = specifiedUrl.path();
         } else {
             *historyFileLocation() = QDir::tempPath();
         }
-        QDir().mkpath(*historyFileLocation());
+        if (!QDir().mkpath(*historyFileLocation())) {
+            qCWarning(KonsoleDebug)<<"Unable to create scrollback folder "<<*historyFileLocation()
+                                   <<" using "<<QDir::homePath();
+            *historyFileLocation() = QDir::homePath();
+        }
     }
     const QString tmpDir = *historyFileLocation();
-    const QString tmpFormat = tmpDir + QLatin1Char('/') + "konsole-XXXXXX.history";
+    const QString tmpFormat = tmpDir + QLatin1Char('/') + QLatin1String("konsole-XXXXXX.history");
     _tmpFile.setFileTemplate(tmpFormat);
     if (_tmpFile.open()) {
         _tmpFile.setAutoRemove(true);
-        _fd = _tmpFile.handle();
     }
 }
 
 HistoryFile::~HistoryFile()
 {
-    if (_fileMap)
+    if (_fileMap != nullptr) {
         unmap();
+    }
 }
 
 //TODO:  Mapping the entire file in will cause problems if the history file becomes exceedingly large,
@@ -102,45 +107,50 @@ void HistoryFile::map()
 {
     Q_ASSERT(_fileMap == 0);
 
-    _fileMap = (char*)mmap(0 , _length , PROT_READ , MAP_PRIVATE , _fd , 0);
+    if (_tmpFile.flush()) {
+        Q_ASSERT(_tmpFile.size() >= _length);
+        _fileMap = _tmpFile.map(0, _length);
+    }
 
     //if mmap'ing fails, fall back to the read-lseek combination
-    if (_fileMap == MAP_FAILED) {
+    if (_fileMap == 0) {
         _readWriteBalance = 0;
-        _fileMap = 0;
-        qWarning() << "mmap'ing history failed.  errno = " << errno;
+        qCDebug(KonsoleDebug) << "mmap'ing history failed.  errno = " << errno;
     }
 }
 
 void HistoryFile::unmap()
 {
-    int result = munmap(_fileMap , _length);
-    Q_ASSERT(result == 0);
-    Q_UNUSED(result);
+    Q_ASSERT(_fileMap != 0);
+
+    if (_tmpFile.unmap(_fileMap))
+        _fileMap = 0;
+
+    Q_ASSERT(_fileMap == 0);
 
-    _fileMap = 0;
 }
 
 bool HistoryFile::isMapped() const
 {
-    return (_fileMap != 0);
+    return _fileMap != 0;
 }
 
-void HistoryFile::add(const unsigned char* buffer, int count)
+void HistoryFile::add(const char *buffer, qint64 count)
 {
-    if (_fileMap)
+    if (_fileMap != nullptr) {
         unmap();
+    }
 
-    _readWriteBalance++;
+    if (_readWriteBalance < INT_MAX)
+        _readWriteBalance++;
 
-    int rc = 0;
+    qint64 rc = 0;
 
-    rc = QT_LSEEK(_fd, _length, SEEK_SET);
-    if (rc < 0) {
+    if (!_tmpFile.seek(_length)) {
         perror("HistoryFile::add.seek");
         return;
     }
-    rc = write(_fd, buffer, count);
+    rc = _tmpFile.write(buffer, count);
     if (rc < 0) {
         perror("HistoryFile::add.write");
         return;
@@ -148,33 +158,34 @@ void HistoryFile::add(const unsigned char* buffer, int count)
     _length += rc;
 }
 
-void HistoryFile::get(unsigned char* buffer, int size, int loc)
+void HistoryFile::get(char *buffer, qint64 size, qint64 loc)
 {
+
+    if (loc < 0 || size < 0 || loc + size > _length) {
+        fprintf(stderr, "getHist(...,%lld,%lld): invalid args.\n", size, loc);
+        return;
+    }
+
     //count number of get() calls vs. number of add() calls.
     //If there are many more get() calls compared with add()
     //calls (decided by using MAP_THRESHOLD) then mmap the log
     //file to improve performance.
-    _readWriteBalance--;
-    if (!_fileMap && _readWriteBalance < MAP_THRESHOLD)
+    if (_readWriteBalance > INT_MIN)
+        _readWriteBalance--;
+    if ((_fileMap == nullptr) && _readWriteBalance < MAP_THRESHOLD) {
         map();
-
-    if (loc < 0 || size < 0 || loc + size > _length) {
-        fprintf(stderr, "getHist(...,%d,%d): invalid args.\n", size, loc);
-        return;
     }
 
-    if (_fileMap) {
-        for (int i = 0; i < size; i++)
-            buffer[i] = _fileMap[loc + i];
+    if (_fileMap != nullptr) {
+        memcpy(buffer, _fileMap + loc, size);
     } else {
-        int rc = 0;
+        qint64 rc = 0;
 
-        rc = QT_LSEEK(_fd, loc, SEEK_SET);
-        if (rc < 0) {
+        if (!_tmpFile.seek(loc)) {
             perror("HistoryFile::get.seek");
             return;
         }
-        rc = read(_fd, buffer, size);
+        rc = _tmpFile.read(buffer, size);
         if (rc < 0) {
             perror("HistoryFile::get.read");
             return;
@@ -182,15 +193,15 @@ void HistoryFile::get(unsigned char* buffer, int size, int loc)
     }
 }
 
-int HistoryFile::len() const
+qint64 HistoryFile::len() const
 {
     return _length;
 }
 
 // History Scroll abstract base class //////////////////////////////////////
 
-HistoryScroll::HistoryScroll(HistoryType* t)
-    : _historyType(t)
+HistoryScroll::HistoryScroll(HistoryType *t) :
+    _historyType(t)
 {
 }
 
@@ -217,18 +228,16 @@ bool HistoryScroll::hasScroll()
    at 0 in cells.
 */
 
-HistoryScrollFile::HistoryScrollFile(const QString& logFileName)
-    : HistoryScroll(new HistoryTypeFile(logFileName))
+HistoryScrollFile::HistoryScrollFile(const QString &logFileName) :
+    HistoryScroll(new HistoryTypeFile(logFileName))
 {
 }
 
-HistoryScrollFile::~HistoryScrollFile()
-{
-}
+HistoryScrollFile::~HistoryScrollFile() = default;
 
 int HistoryScrollFile::getLines()
 {
-    return _index.len() / sizeof(int);
+    return _index.len() / sizeof(qint64);
 }
 
 int HistoryScrollFile::getLineLen(int lineno)
@@ -239,22 +248,22 @@ int HistoryScrollFile::getLineLen(int lineno)
 bool HistoryScrollFile::isWrappedLine(int lineno)
 {
     if (lineno >= 0 && lineno <= getLines()) {
-        unsigned char flag;
-        _lineflags.get((unsigned char*)&flag, sizeof(unsigned char), (lineno)*sizeof(unsigned char));
-        return flag;
+        unsigned char flag = 0;
+        _lineflags.get((char *)&flag, sizeof(unsigned char),
+                       (lineno)*sizeof(unsigned char));
+        return flag != 0u;
     }
     return false;
 }
 
-int HistoryScrollFile::startOfLine(int lineno)
+qint64 HistoryScrollFile::startOfLine(int lineno)
 {
-    if (lineno <= 0) return 0;
+    if (lineno <= 0) {
+        return 0;
+    }
     if (lineno <= getLines()) {
-        if (!_index.isMapped())
-            _index.map();
-
-        int res;
-        _index.get((unsigned char*)&res, sizeof(int), (lineno - 1)*sizeof(int));
+        qint64 res;
+        _index.get((char*)&res, sizeof(qint64), (lineno - 1)*sizeof(qint64));
         return res;
     }
     return _cells.len();
@@ -262,47 +271,42 @@ int HistoryScrollFile::startOfLine(int lineno)
 
 void HistoryScrollFile::getCells(int lineno, int colno, int count, Character res[])
 {
-    _cells.get((unsigned char*)res, count * sizeof(Character), startOfLine(lineno) + colno * sizeof(Character));
+    _cells.get((char*)res, count * sizeof(Character), startOfLine(lineno) + colno * sizeof(Character));
 }
 
 void HistoryScrollFile::addCells(const Character text[], int count)
 {
-    _cells.add((unsigned char*)text, count * sizeof(Character));
+    _cells.add((char*)text, count * sizeof(Character));
 }
 
 void HistoryScrollFile::addLine(bool previousWrapped)
 {
-    if (_index.isMapped())
-        _index.unmap();
-
-    int locn = _cells.len();
-    _index.add((unsigned char*)&locn, sizeof(int));
+    qint64 locn = _cells.len();
+    _index.add((char *)&locn, sizeof(qint64));
     unsigned char flags = previousWrapped ? 0x01 : 0x00;
-    _lineflags.add((unsigned char*)&flags, sizeof(unsigned char));
+    _lineflags.add((char *)&flags, sizeof(char));
 }
 
 // History Scroll None //////////////////////////////////////
 
-HistoryScrollNone::HistoryScrollNone()
-    : HistoryScroll(new HistoryTypeNone())
+HistoryScrollNone::HistoryScrollNone() :
+    HistoryScroll(new HistoryTypeNone())
 {
 }
 
-HistoryScrollNone::~HistoryScrollNone()
-{
-}
+HistoryScrollNone::~HistoryScrollNone() = default;
 
 bool HistoryScrollNone::hasScroll()
 {
     return false;
 }
 
-int  HistoryScrollNone::getLines()
+int HistoryScrollNone::getLines()
 {
     return 0;
 }
 
-int  HistoryScrollNone::getLineLen(int)
+int HistoryScrollNone::getLineLen(int)
 {
     return 0;
 }
@@ -327,13 +331,14 @@ void HistoryScrollNone::addLine(bool)
 ////////////////////////////////////////////////////////////////
 // Compact History Scroll //////////////////////////////////////
 ////////////////////////////////////////////////////////////////
-void* CompactHistoryBlock::allocate(size_t size)
+void *CompactHistoryBlock::allocate(size_t size)
 {
     Q_ASSERT(size > 0);
-    if (_tail - _blockStart + size > _blockLength)
+    if (_tail - _blockStart + size > _blockLength) {
         return 0;
+    }
 
-    void* block = _tail;
+    void *block = _tail;
     _tail += size;
     ////qDebug() << "allocated " << length << " bytes at address " << block;
     _allocCount++;
@@ -346,9 +351,9 @@ void CompactHistoryBlock::deallocate()
     Q_ASSERT(_allocCount >= 0);
 }
 
-void* CompactHistoryBlockList::allocate(size_t size)
+void *CompactHistoryBlockList::allocate(size_t size)
 {
-    CompactHistoryBlock* block;
+    CompactHistoryBlock *block;
     if (list.isEmpty() || list.last()->remaining() < size) {
         block = new CompactHistoryBlock();
         list.append(block);
@@ -360,12 +365,12 @@ void* CompactHistoryBlockList::allocate(size_t size)
     return block->allocate(size);
 }
 
-void CompactHistoryBlockList::deallocate(void* ptr)
+void CompactHistoryBlockList::deallocate(void *ptr)
 {
     Q_ASSERT(!list.isEmpty());
 
     int i = 0;
-    CompactHistoryBlock* block = list.at(i);
+    CompactHistoryBlock *block = list.at(i);
     while (i < list.size() && !block->contains(ptr)) {
         i++;
         block = list.at(i);
@@ -388,17 +393,17 @@ CompactHistoryBlockList::~CompactHistoryBlockList()
     list.clear();
 }
 
-void* CompactHistoryLine::operator new(size_t size, CompactHistoryBlockList& blockList)
+void *CompactHistoryLine::operator new(size_t size, CompactHistoryBlockList &blockList)
 {
     return blockList.allocate(size);
 }
 
-CompactHistoryLine::CompactHistoryLine(const TextLine& line, CompactHistoryBlockList& bList)
-    : _blockListRef(bList),
-      _formatArray(0),
-      _text(0),
-      _formatLength(0),
-      _wrapped(false)
+CompactHistoryLine::CompactHistoryLine(const TextLine &line, CompactHistoryBlockList &bList) :
+    _blockListRef(bList),
+    _formatArray(0),
+    _text(0),
+    _formatLength(0),
+    _wrapped(false)
 {
     _length = line.size();
 
@@ -417,9 +422,9 @@ CompactHistoryLine::CompactHistoryLine(const TextLine& line, CompactHistoryBlock
         }
 
         ////qDebug() << "number of different formats in string: " << _formatLength;
-        _formatArray = (CharacterFormat*) _blockListRef.allocate(sizeof(CharacterFormat) * _formatLength);
+        _formatArray = (CharacterFormat *)_blockListRef.allocate(sizeof(CharacterFormat) * _formatLength);
         Q_ASSERT(_formatArray != 0);
-        _text = (quint16*) _blockListRef.allocate(sizeof(quint16) * line.size());
+        _text = (quint16 *)_blockListRef.allocate(sizeof(quint16) * line.size());
         Q_ASSERT(_text != 0);
 
         _length = line.size();
@@ -461,12 +466,13 @@ CompactHistoryLine::~CompactHistoryLine()
     _blockListRef.deallocate(this);
 }
 
-void CompactHistoryLine::getCharacter(int index, Character& r)
+void CompactHistoryLine::getCharacter(int index, Character &r)
 {
     Q_ASSERT(index < _length);
     int formatPos = 0;
-    while ((formatPos + 1) < _formatLength && index >= _formatArray[formatPos + 1].startPos)
+    while ((formatPos + 1) < _formatLength && index >= _formatArray[formatPos + 1].startPos) {
         formatPos++;
+    }
 
     r.character = _text[index];
     r.rendition = _formatArray[formatPos].rendition;
@@ -475,7 +481,7 @@ void CompactHistoryLine::getCharacter(int index, Character& r)
     r.isRealCharacter = _formatArray[formatPos].isRealCharacter;
 }
 
-void CompactHistoryLine::getCharacters(Character* array, int size, int startColumn)
+void CompactHistoryLine::getCharacters(Character *array, int size, int startColumn)
 {
     Q_ASSERT(startColumn >= 0 && size >= 0);
     Q_ASSERT(startColumn + size <= static_cast<int>(getLength()));
@@ -485,10 +491,10 @@ void CompactHistoryLine::getCharacters(Character* array, int size, int startColu
     }
 }
 
-CompactHistoryScroll::CompactHistoryScroll(unsigned int maxLineCount)
-    : HistoryScroll(new CompactHistoryType(maxLineCount))
-    , _lines()
-    , _blockList()
+CompactHistoryScroll::CompactHistoryScroll(unsigned int maxLineCount) :
+    HistoryScroll(new CompactHistoryType(maxLineCount)),
+    _lines(),
+    _blockList()
 {
     ////qDebug() << "scroll of length " << maxLineCount << " created";
     setMaxNbLines(maxLineCount);
@@ -500,9 +506,9 @@ CompactHistoryScroll::~CompactHistoryScroll()
     _lines.clear();
 }
 
-void CompactHistoryScroll::addCellsVector(const TextLine& cells)
+void CompactHistoryScroll::addCellsVector(const TextLine &cells)
 {
-    CompactHistoryLine* line;
+    CompactHistoryLine *line;
     line = new(_blockList) CompactHistoryLine(cells, _blockList);
 
     if (_lines.size() > static_cast<int>(_maxLineCount)) {
@@ -520,7 +526,7 @@ void CompactHistoryScroll::addCells(const Character a[], int count)
 
 void CompactHistoryScroll::addLine(bool previousWrapped)
 {
-    CompactHistoryLine* line = _lines.last();
+    CompactHistoryLine *line = _lines.last();
     ////qDebug() << "last line at address " << line;
     line->setWrapped(previousWrapped);
 }
@@ -537,16 +543,18 @@ int CompactHistoryScroll::getLineLen(int lineNumber)
         //Q_ASSERT(lineNumber >= 0 && lineNumber < _lines.size());
         return 0;
     }
-    CompactHistoryLine* line = _lines[lineNumber];
+    CompactHistoryLine *line = _lines[lineNumber];
     ////qDebug() << "request for line at address " << line;
     return line->getLength();
 }
 
 void CompactHistoryScroll::getCells(int lineNumber, int startColumn, int count, Character buffer[])
 {
-    if (count == 0) return;
+    if (count == 0) {
+        return;
+    }
     Q_ASSERT(lineNumber < _lines.size());
-    CompactHistoryLine* line = _lines[lineNumber];
+    CompactHistoryLine *line = _lines[lineNumber];
     Q_ASSERT(startColumn >= 0);
     Q_ASSERT((unsigned int)startColumn <= line->getLength() - count);
     line->getCharacters(buffer, count, startColumn);
@@ -572,13 +580,8 @@ bool CompactHistoryScroll::isWrappedLine(int lineNumber)
 // History Types
 //////////////////////////////////////////////////////////////////////
 
-HistoryType::HistoryType()
-{
-}
-
-HistoryType::~HistoryType()
-{
-}
+HistoryType::HistoryType() = default;
+HistoryType::~HistoryType() = default;
 
 //////////////////////////////
 
@@ -591,7 +594,7 @@ bool HistoryTypeNone::isEnabled() const
     return false;
 }
 
-HistoryScroll* HistoryTypeNone::scroll(HistoryScroll* old) const
+HistoryScroll *HistoryTypeNone::scroll(HistoryScroll *old) const
 {
     delete old;
     return new HistoryScrollNone();
@@ -604,8 +607,8 @@ int HistoryTypeNone::maximumLineCount() const
 
 //////////////////////////////
 
-HistoryTypeFile::HistoryTypeFile(const QString& fileName)
-    : _fileName(fileName)
+HistoryTypeFile::HistoryTypeFile(const QString &fileName) :
+    _fileName(fileName)
 {
 }
 
@@ -614,19 +617,19 @@ bool HistoryTypeFile::isEnabled() const
     return true;
 }
 
-HistoryScroll* HistoryTypeFile::scroll(HistoryScroll* old) const
+HistoryScroll *HistoryTypeFile::scroll(HistoryScroll *old) const
 {
-    if (dynamic_cast<HistoryFile *>(old))
+    if (dynamic_cast<HistoryFile *>(old) != nullptr) {
         return old; // Unchanged.
-
-    HistoryScroll* newScroll = new HistoryScrollFile(_fileName);
+    }
+    HistoryScroll *newScroll = new HistoryScrollFile(_fileName);
 
     Character line[LINE_SIZE];
     int lines = (old != 0) ? old->getLines() : 0;
     for (int i = 0; i < lines; i++) {
         int size = old->getLineLen(i);
         if (size > LINE_SIZE) {
-            Character* tmp_line = new Character[size];
+            auto tmp_line = new Character[size];
             old->getCells(i, 0, size, tmp_line);
             newScroll->addCells(tmp_line, size);
             newScroll->addLine(old->isWrappedLine(i));
@@ -649,8 +652,8 @@ int HistoryTypeFile::maximumLineCount() const
 
 //////////////////////////////
 
-CompactHistoryType::CompactHistoryType(unsigned int nbLines)
-    : _maxLines(nbLines)
+CompactHistoryType::CompactHistoryType(unsigned int nbLines) :
+    _maxLines(nbLines)
 {
 }
 
@@ -664,11 +667,11 @@ int CompactHistoryType::maximumLineCount() const
     return _maxLines;
 }
 
-HistoryScroll* CompactHistoryType::scroll(HistoryScroll* old) const
+HistoryScroll *CompactHistoryType::scroll(HistoryScroll *old) const
 {
-    if (old) {
-        CompactHistoryScroll* oldBuffer = dynamic_cast<CompactHistoryScroll*>(old);
-        if (oldBuffer) {
+    if (old != nullptr) {
+        CompactHistoryScroll *oldBuffer = dynamic_cast<CompactHistoryScroll *>(old);
+        if (oldBuffer != nullptr) {
             oldBuffer->setMaxNbLines(_maxLines);
             return oldBuffer;
         }
